<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>dcc::datetime::Country</name>
    <message>
        <source>Bermuda</source>
        <translation>Bermuda</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Greenland</source>
        <translation>Grönland</translation>
    </message>
    <message>
        <source>St. Pierre </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>United States</source>
        <translation>Vereinigte Staaten</translation>
    </message>
    <message>
        <source>US</source>
        <translation>US</translation>
    </message>
    <message>
        <source>Belize</source>
        <translation>Belize</translation>
    </message>
    <message>
        <source>Costa Rica</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Guatemala</source>
        <translation>Guatemala</translation>
    </message>
    <message>
        <source>Honduras</source>
        <translation>Honduras</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexiko</translation>
    </message>
    <message>
        <source>Nicaragua</source>
        <translation>Nicaragua</translation>
    </message>
    <message>
        <source>Panama</source>
        <translation>Panama</translation>
    </message>
    <message>
        <source>El Salvador</source>
        <translation>El Salvador</translation>
    </message>
    <message>
        <source>Antigua </source>
        <translation>Antigua </translation>
    </message>
    <message>
        <source>Anguilla</source>
        <translation>Anguilla</translation>
    </message>
    <message>
        <source>Aruba</source>
        <translation>Aruba</translation>
    </message>
    <message>
        <source>Barbados</source>
        <translation>Barbados</translation>
    </message>
    <message>
        <source>St. Barthélemy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Caribbean Netherlands</source>
        <translation>Karibische Niederlande</translation>
    </message>
    <message>
        <source>Bahamas</source>
        <translation>Bahamas</translation>
    </message>
    <message>
        <source>Cuba</source>
        <translation>Kuba</translation>
    </message>
    <message>
        <source>Curaçao</source>
        <translation>Curaçao</translation>
    </message>
    <message>
        <source>Dominica</source>
        <translation>Dominica</translation>
    </message>
    <message>
        <source>Dominican Republic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Grenada</source>
        <translation>Grenada</translation>
    </message>
    <message>
        <source>Guadeloupe</source>
        <translation>Guadeloupe</translation>
    </message>
    <message>
        <source>Haiti</source>
        <translation>Haiti</translation>
    </message>
    <message>
        <source>Jamaica</source>
        <translation>Jamaika</translation>
    </message>
    <message>
        <source>St. Kitts </source>
        <translation>St. Kitts </translation>
    </message>
    <message>
        <source>Cayman Islands</source>
        <translation>Kaimaninseln</translation>
    </message>
    <message>
        <source>St. Lucia</source>
        <translation>St. Lucia</translation>
    </message>
    <message>
        <source>St. Martin</source>
        <translation>St. Martin</translation>
    </message>
    <message>
        <source>Martinique</source>
        <translation>Martinique</translation>
    </message>
    <message>
        <source>Montserrat</source>
        <translation>Montserrat</translation>
    </message>
    <message>
        <source>Puerto Rico</source>
        <translation>Puerto Rico</translation>
    </message>
    <message>
        <source>Sint Maarten</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turks </source>
        <translation>Turks </translation>
    </message>
    <message>
        <source>Trinidad </source>
        <translation>Trinidad </translation>
    </message>
    <message>
        <source>St. Vincent </source>
        <translation>St. Vincent </translation>
    </message>
    <message>
        <source>British Virgin Islands</source>
        <translation>Britische Jungferninseln</translation>
    </message>
    <message>
        <source>U.S. Virgin Islands</source>
        <translation>Amerikanische Jungferninseln</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentinien</translation>
    </message>
    <message>
        <source>Bolivia</source>
        <translation>Bolivien</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasilien</translation>
    </message>
    <message>
        <source>Bouvet Island</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbien</translation>
    </message>
    <message>
        <source>Ecuador</source>
        <translation>Ecuador</translation>
    </message>
    <message>
        <source>Falkland Islands</source>
        <translation>Falklandinseln</translation>
    </message>
    <message>
        <source>Falkland Islands (Islas Malvinas)</source>
        <translation>Falklandinseln (Malwinen)</translation>
    </message>
    <message>
        <source>French Guiana</source>
        <translation>Französisch-Guayana</translation>
    </message>
    <message>
        <source>South Georgia </source>
        <translation>Südgeorgien</translation>
    </message>
    <message>
        <source>Guyana</source>
        <translation>Guyana</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Paraguay</source>
        <translation>Paraguay</translation>
    </message>
    <message>
        <source>Suriname</source>
        <translation>Suriname</translation>
    </message>
    <message>
        <source>Uruguay</source>
        <translation>Uruguay</translation>
    </message>
    <message>
        <source>Venezuela</source>
        <translation>Venezuela</translation>
    </message>
    <message>
        <source>Algeria</source>
        <translation>Algerien</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Ägypten</translation>
    </message>
    <message>
        <source>Western Sahara</source>
        <translation>Westsahara</translation>
    </message>
    <message>
        <source>Libya</source>
        <translation>Libyen</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marokko</translation>
    </message>
    <message>
        <source>Sudan</source>
        <translation>Sudan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunesien</translation>
    </message>
    <message>
        <source>Ceuta </source>
        <translation>Ceuta </translation>
    </message>
    <message>
        <source>Canary Islands</source>
        <translation>Kanarische Inseln</translation>
    </message>
    <message>
        <source>Burkina Faso</source>
        <translation>Burkina Faso</translation>
    </message>
    <message>
        <source>Benin</source>
        <translation>Benin</translation>
    </message>
    <message>
        <source>Côte d’Ivoire</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ivory Coast</source>
        <translation>Elfenbeinküste</translation>
    </message>
    <message>
        <source>Cape Verde</source>
        <translation>Kap Verde</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Gambia</source>
        <translation>Gambia</translation>
    </message>
    <message>
        <source>Guinea</source>
        <translation>Guinea</translation>
    </message>
    <message>
        <source>Guinea-Bissau</source>
        <translation>Guinea-Bissau</translation>
    </message>
    <message>
        <source>Liberia</source>
        <translation>Liberia</translation>
    </message>
    <message>
        <source>Mali</source>
        <translation>Mali</translation>
    </message>
    <message>
        <source>Mauritania</source>
        <translation>Mauritanien</translation>
    </message>
    <message>
        <source>Niger</source>
        <translation>Niger</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>St. Helena</source>
        <translation>St. Helena</translation>
    </message>
    <message>
        <source>Sierra Leone</source>
        <translation>Sierra Leone</translation>
    </message>
    <message>
        <source>Senegal</source>
        <translation>Senegal</translation>
    </message>
    <message>
        <source>Togo</source>
        <translation>Togo</translation>
    </message>
    <message>
        <source>Angola</source>
        <translation>Angola</translation>
    </message>
    <message>
        <source>Congo - Kinshasa</source>
        <translation>Kongo - Kinshasa</translation>
    </message>
    <message>
        <source>Congo (DRC)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Central African Republic</source>
        <translation>Zentralafrikanische Republik</translation>
    </message>
    <message>
        <source>Congo - Brazzaville</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Congo (Republic)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cameroon</source>
        <translation>Kamerun</translation>
    </message>
    <message>
        <source>Gabon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Equatorial Guinea</source>
        <translation>Äquatorialguinea</translation>
    </message>
    <message>
        <source>São Tomé </source>
        <translation>São Tomé </translation>
    </message>
    <message>
        <source>Chad</source>
        <translation>Tschad</translation>
    </message>
    <message>
        <source>Burundi</source>
        <translation>Burundi</translation>
    </message>
    <message>
        <source>Djibouti</source>
        <translation>Dschibuti</translation>
    </message>
    <message>
        <source>Eritrea</source>
        <translation>Eritrea</translation>
    </message>
    <message>
        <source>Ethiopia</source>
        <translation>Äthiopien</translation>
    </message>
    <message>
        <source>British Indian Ocean Territory</source>
        <translation>Britisches Territorium im Indischen Ozean</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenia</translation>
    </message>
    <message>
        <source>Comoros</source>
        <translation>Komoren</translation>
    </message>
    <message>
        <source>Madagascar</source>
        <translation>Madagaskar</translation>
    </message>
    <message>
        <source>Mauritius</source>
        <translation>Mauritius</translation>
    </message>
    <message>
        <source>Malawi</source>
        <translation>Malawi</translation>
    </message>
    <message>
        <source>Mozambique</source>
        <translation>Mosambik</translation>
    </message>
    <message>
        <source>Réunion</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rwanda</source>
        <translation>Ruanda</translation>
    </message>
    <message>
        <source>Seychelles</source>
        <translation>Seychellen</translation>
    </message>
    <message>
        <source>Somalia</source>
        <translation>Somalia</translation>
    </message>
    <message>
        <source>South Sudan</source>
        <translation>Südsudan</translation>
    </message>
    <message>
        <source>French Southern Territories</source>
        <translation>Französische Südgebiete</translation>
    </message>
    <message>
        <source>Tanzania</source>
        <translation>Tansania</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>Mayotte</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zambia</source>
        <translation>Sambia</translation>
    </message>
    <message>
        <source>Zimbabwe</source>
        <translation>Simbabwe</translation>
    </message>
    <message>
        <source>Botswana</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lesotho</source>
        <translation>Lesotho</translation>
    </message>
    <message>
        <source>Namibia</source>
        <translation>Namibia</translation>
    </message>
    <message>
        <source>Eswatini</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Südafrika</translation>
    </message>
    <message>
        <source>Guernsey</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Isle of Man</source>
        <translation>Insel Man</translation>
    </message>
    <message>
        <source>Jersey</source>
        <translation>Jersey</translation>
    </message>
    <message>
        <source>Åland Islands</source>
        <translation>Åland-Inseln</translation>
    </message>
    <message>
        <source>Denmark</source>
        <translation>Dänemark</translation>
    </message>
    <message>
        <source>Estonia</source>
        <translation>Estland</translation>
    </message>
    <message>
        <source>Finland</source>
        <translation>Finnland</translation>
    </message>
    <message>
        <source>Faroe Islands</source>
        <translation>Färöer-Inseln</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Vereinigtes Königreich</translation>
    </message>
    <message>
        <source>UK</source>
        <translation>UK</translation>
    </message>
    <message>
        <source>England</source>
        <translation>England</translation>
    </message>
    <message>
        <source>Scotland</source>
        <translation>Schottland</translation>
    </message>
    <message>
        <source>Wales</source>
        <translation>Wales</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irland</translation>
    </message>
    <message>
        <source>Iceland</source>
        <translation>Island</translation>
    </message>
    <message>
        <source>Lithuania</source>
        <translation>Litauen</translation>
    </message>
    <message>
        <source>Latvia</source>
        <translation>Lettland</translation>
    </message>
    <message>
        <source>Norway</source>
        <translation>Norwegen</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Schweden</translation>
    </message>
    <message>
        <source>Svalbard </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Austria</source>
        <translation>Österreich</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgien</translation>
    </message>
    <message>
        <source>Switzerland</source>
        <translation>Schweiz</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Deutschland</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Frankreich</translation>
    </message>
    <message>
        <source>Liechtenstein</source>
        <translation>Liechtenstein</translation>
    </message>
    <message>
        <source>Luxembourg</source>
        <translation>Luxemburg</translation>
    </message>
    <message>
        <source>Monaco</source>
        <translation>Monaco</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Niederlande</translation>
    </message>
    <message>
        <source>Bulgaria</source>
        <translation>Bulgarien</translation>
    </message>
    <message>
        <source>Belarus</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Czechia</source>
        <translation>Tschechien</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Tschechische Republik</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Ungarn</translation>
    </message>
    <message>
        <source>Moldova</source>
        <translation>Moldau</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polen</translation>
    </message>
    <message>
        <source>Romania</source>
        <translation>Rumänien</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Russland</translation>
    </message>
    <message>
        <source>Slovakia</source>
        <translation>Slowakei</translation>
    </message>
    <message>
        <source>Ukraine</source>
        <translation>Ukraine</translation>
    </message>
    <message>
        <source>Andorra</source>
        <translation>Andorra</translation>
    </message>
    <message>
        <source>Albania</source>
        <translation>Albanien</translation>
    </message>
    <message>
        <source>Bosnia </source>
        <translation>Bosnien</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spanien</translation>
    </message>
    <message>
        <source>Gibraltar</source>
        <translation>Gibraltar</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Griechenland</translation>
    </message>
    <message>
        <source>Croatia</source>
        <translation>Kroatien</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italien</translation>
    </message>
    <message>
        <source>Montenegro</source>
        <translation>Montenegro</translation>
    </message>
    <message>
        <source>North Macedonia</source>
        <translation>Nordmazedonien</translation>
    </message>
    <message>
        <source>Malta</source>
        <translation>Malta</translation>
    </message>
    <message>
        <source>Serbia</source>
        <translation>Serbien</translation>
    </message>
    <message>
        <source>Portugal</source>
        <translation>Portugal</translation>
    </message>
    <message>
        <source>Slovenia</source>
        <translation>Slowenien</translation>
    </message>
    <message>
        <source>San Marino</source>
        <translation>San Marino</translation>
    </message>
    <message>
        <source>Vatican City</source>
        <translation>Vatikanstadt</translation>
    </message>
    <message>
        <source>Kosovo</source>
        <translation>Kosovo</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Vereinigte Arabische Emirate</translation>
    </message>
    <message>
        <source>Armenia</source>
        <translation>Armenien</translation>
    </message>
    <message>
        <source>Azerbaijan</source>
        <translation>Aserbaidschan</translation>
    </message>
    <message>
        <source>Bahrain</source>
        <translation>Bahrain</translation>
    </message>
    <message>
        <source>Cyprus</source>
        <translation>Zypern</translation>
    </message>
    <message>
        <source>Georgia</source>
        <translation>Georgien</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Iraq</source>
        <translation>Irak</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordanien</translation>
    </message>
    <message>
        <source>Kuwait</source>
        <translation>Kuwait</translation>
    </message>
    <message>
        <source>Lebanon</source>
        <translation>Libanon</translation>
    </message>
    <message>
        <source>Oman</source>
        <translation>Oman</translation>
    </message>
    <message>
        <source>Palestinian Territories</source>
        <translation>Palästinensische Gebiete</translation>
    </message>
    <message>
        <source>Palestine</source>
        <translation>Palästina</translation>
    </message>
    <message>
        <source>Qatar</source>
        <translation>Katar</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudi-Arabien</translation>
    </message>
    <message>
        <source>Syria</source>
        <translation>Syrien</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Türkei</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Turkmenistan</source>
        <translation>Turkmenistan</translation>
    </message>
    <message>
        <source>Tajikistan</source>
        <translation>Tadschikistan</translation>
    </message>
    <message>
        <source>Kyrgyzstan</source>
        <translation>Kirgisistan</translation>
    </message>
    <message>
        <source>Kazakhstan</source>
        <translation>Kasachstan</translation>
    </message>
    <message>
        <source>Uzbekistan</source>
        <translation>Usbekistan</translation>
    </message>
    <message>
        <source>China</source>
        <translation>China</translation>
    </message>
    <message>
        <source>Hong Kong SAR China</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <source>North Korea</source>
        <translation>Nordkorea</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Südkorea</translation>
    </message>
    <message>
        <source>Mongolia</source>
        <translation>Mongolei</translation>
    </message>
    <message>
        <source>Macao SAR China</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Macao</source>
        <translation>Macao</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Afghanistan</source>
        <translation>Afghanistan</translation>
    </message>
    <message>
        <source>Bangladesh</source>
        <translation>Bangladesch</translation>
    </message>
    <message>
        <source>Bhutan</source>
        <translation>Bhutan</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indien</translation>
    </message>
    <message>
        <source>Iran</source>
        <translation>Iran</translation>
    </message>
    <message>
        <source>Sri Lanka</source>
        <translation>Sri Lanka</translation>
    </message>
    <message>
        <source>Maldives</source>
        <translation>Malediven</translation>
    </message>
    <message>
        <source>Nepal</source>
        <translation>Nepal</translation>
    </message>
    <message>
        <source>Pakistan</source>
        <translation>Pakistan</translation>
    </message>
    <message>
        <source>Brunei</source>
        <translation>Brunei</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesien</translation>
    </message>
    <message>
        <source>Cambodia</source>
        <translation>Kambodscha</translation>
    </message>
    <message>
        <source>Laos</source>
        <translation>Laos</translation>
    </message>
    <message>
        <source>Myanmar (Burma)</source>
        <translation>Myanmar (Burma)</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Philippinen</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>Thailand</source>
        <translation>Thailand</translation>
    </message>
    <message>
        <source>Timor-Leste</source>
        <translation>Osttimor</translation>
    </message>
    <message>
        <source>Vietnam</source>
        <translation>Vietnam</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australien</translation>
    </message>
    <message>
        <source>Cocos (Keeling) Islands</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Christmas Island</source>
        <translation>Weihnachtsinsel</translation>
    </message>
    <message>
        <source>Heard </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Norfolk Island</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Neuseeland</translation>
    </message>
    <message>
        <source>Fiji</source>
        <translation>Fidschi</translation>
    </message>
    <message>
        <source>New Caledonia</source>
        <translation>Neukaledonien</translation>
    </message>
    <message>
        <source>Papua New Guinea</source>
        <translation>Papua-Neuguinea</translation>
    </message>
    <message>
        <source>Solomon Islands</source>
        <translation>Salomon-Inseln</translation>
    </message>
    <message>
        <source>Vanuatu</source>
        <translation>Vanuatu</translation>
    </message>
    <message>
        <source>Micronesia</source>
        <translation>Mikronesien</translation>
    </message>
    <message>
        <source>Guam</source>
        <translation>Guam</translation>
    </message>
    <message>
        <source>Kiribati</source>
        <translation>Kiribati</translation>
    </message>
    <message>
        <source>Marshall Islands</source>
        <translation>Marshallinseln</translation>
    </message>
    <message>
        <source>Northern Mariana Islands</source>
        <translation>Nördliche Marianen</translation>
    </message>
    <message>
        <source>Nauru</source>
        <translation>Nauru</translation>
    </message>
    <message>
        <source>Palau</source>
        <translation>Palau</translation>
    </message>
    <message>
        <source>U.S. Outlying Islands</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>American Samoa</source>
        <translation>Amerikanisch-Samoa</translation>
    </message>
    <message>
        <source>Cook Islands</source>
        <translation>Cookinseln</translation>
    </message>
    <message>
        <source>Niue</source>
        <translation>Niue</translation>
    </message>
    <message>
        <source>French Polynesia</source>
        <translation>Französisch-Polynesien</translation>
    </message>
    <message>
        <source>Pitcairn Islands</source>
        <translation>Pitcairninseln</translation>
    </message>
    <message>
        <source>Tokelau</source>
        <translation>Tokelau</translation>
    </message>
    <message>
        <source>Tonga</source>
        <translation>Tonga</translation>
    </message>
    <message>
        <source>Tuvalu</source>
        <translation>Tuvalu</translation>
    </message>
    <message>
        <source>Wallis</source>
        <translation>Wallis</translation>
    </message>
    <message>
        <source>Samoa</source>
        <translation>Samoa</translation>
    </message>
    <message>
        <source>Antarctica</source>
        <translation>Antarktis</translation>
    </message>
    <message>
        <source>Ascension Island</source>
        <translation>Ascension</translation>
    </message>
    <message>
        <source>Clipperton Island</source>
        <translation>Clipperton-Insel</translation>
    </message>
    <message>
        <source>Diego Garcia</source>
        <translation>Diego Garcia</translation>
    </message>
    <message>
        <source>Tristan da Cunha</source>
        <translation>Tristan da Cunha</translation>
    </message>
    <message>
        <source>Macedonia</source>
        <translation>Mazedonien</translation>
    </message>
    <message>
        <source>World</source>
        <translation>Welt</translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Macau</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bosnia And Herzegowina</source>
        <translation>Bosnien und Herzegowina</translation>
    </message>
    <message>
        <source>Cura Sao</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bonaire</source>
        <translation>Bonaire</translation>
    </message>
    <message>
        <source>Antigua And Barbuda</source>
        <translation>Antigua und Barbuda</translation>
    </message>
    <message>
        <source>Cocos Islands</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pitcairn</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saint Kitts And Nevis</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saint Lucia</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saint Vincent And The Grenadines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saint Helena</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swaziland</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trinidad And Tobago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turks And Caicos Islands</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>United States Minor Outlying Islands</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>United States Virgin Islands</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Isle Of Man</source>
        <translation>Insel Man</translation>
    </message>
    <message>
        <source>Europe</source>
        <translation>Europa</translation>
    </message>
    <message>
        <source>Congo Kinshasa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Congo Brazzaville</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reunion</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saint Pierre And Miquelon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wallis And Futuna Islands</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saint Barthelemy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saint Martin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Vatican City State</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Svalbard And Jan Mayen Islands</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>East Timor</source>
        <translation>Osttimor</translation>
    </message>
    <message>
        <source>Guinea Bissau</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sao Tome And Principe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Latin America</source>
        <translation>Lateinamerika</translation>
    </message>
    <message>
        <source>Ceuta And Melilla</source>
        <translation>Ceuta und Melilla</translation>
    </message>
    <message>
        <source>Aland Islands</source>
        <translation>Åland-Inseln</translation>
    </message>
</context>
</TS>